@@ -627,6 +627,7 @@ sub body_accordion
 </div>
 
 <!--end Content-->
+
 }; 
 	
 	if ($ARGV and $ARGV > 0 or scalar(@keys) > 0) 
@@ -634,11 +635,11 @@ sub body_accordion
 		
 		if (@_) 
 		{
-			return qq{@_\n}; 
+			return qq{\n@_\n}; 
 		}
 		else 
 		{
-			return qq{\n<!--525--> \n$out\n}; 
+			return qq{\n$out\n}; 
 		}
 		
 	}
@@ -730,7 +731,7 @@ sub body_form
 	my $out; 
 	
 	my @keys;  
-	if (@_) { @keys = @_; } 
+	if (@_) { @keys = "@_"; } 
 	
 	my ($vars, $vals) = (''); 
 	for (@keys) 
@@ -976,7 +977,7 @@ sub html_navbar
 		-nbMenuName 	=>	"", 
 		-nbPageName 	=> 	"",
 		-nbServer    =>  "",
-		-nbLinks => "blog-support-help-contact-sale"
+		-nbLinks => "blog-support-help-contact-sale",
 		@_,		
 	);
 	
@@ -1748,7 +1749,7 @@ A1z::HTML5::Template - Fast/easy Web Apps in Perl
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -1828,7 +1829,7 @@ version 0.10
 
 =head1 VERSION
 
-	Version 0.10
+	Version 0.11
 
 =head1 METHODS
 
@@ -1945,7 +1946,9 @@ version 0.10
 
 =head2 body_accordion
 
-	say $h->body_accordion( $h->open_file("C:/Users/user/public/app/open_file_example.txt", 'Type', 'Header') ); 
+	body_accordion is misleading. It is not limited to accordion but all kinds of content.
+
+	C<<< say $h->body_accordion( $h->open_file("/path/to/app/open_file_example.txt", 'Type', 'h2 Heading') ); >>>
 
 =head2 body_article
 
